@@ -1,13 +1,14 @@
 import datetime
 import functools
-import math
 import operator
 import os
 from multiprocessing.dummy import Pool
+from pathlib import Path
 from typing import Union, List, Tuple, Iterator
 
 from . import params, settings, util
 from .api.models import Artwork
+from .texts import texts
 
 __all__ = ['PikaxResult', 'PikaxUserInterface', 'PikaxInterface', 'PikaxPagesInterface', 'BaseDownloader']
 
@@ -108,7 +109,8 @@ class PikaxResult:
 
         def _compare(self, compare_operator, value):
             operator_symbol = self._operator_to_symbol[compare_operator]
-            util.log(f'Filtering {self.name} {operator_symbol} {value}', start=os.linesep, inform=True)
+            util.log(texts.FILTER_INFO.format(name=self.name, operator_symbol=operator_symbol, value=value),
+                     start=os.linesep, inform=True)
 
             old_len = len(self.outer_self.artworks)
             new_artworks = list(
@@ -119,7 +121,7 @@ class PikaxResult:
             folder = util.clean_filename(str(self.outer_self.folder) + '_' + operator_name + '_' + str(value))
             result = self.result_maker(artworks=new_artworks, folder=folder)
 
-            util.log(f'[ done ] {old_len} => {new_len}', inform=True)
+            util.log(texts.DONE_INFO.format(old=old_len, new=new_len), inform=True)
             return result
 
     @property
@@ -138,6 +140,10 @@ class PikaxResult:
     def download_type(self) -> params.DownloadType:
         return self._download_type
 
+    # workaround for gui to change artwork using the same download type and folder
+    def renew_artworks(self, param):
+        raise NotImplementedError
+
 
 class PikaxUserInterface:
     """
@@ -326,33 +332,6 @@ class BaseDownloader:
             params.DownloadType.MANGA: self.download_manga,
         }
 
-    # @staticmethod
-    # def config_artworks(artworks: List[Artwork]):
-    #     util.log('Configuring artworks', start=os.linesep, inform=True)
-    #     total = len(artworks)
-    #     config_artworks = []
-    #     failed_config_artworks = dict()  # reason map to artwork
-    #     pool = Pool()
-    #
-    #     def config_artwork(artwork_item):
-    #         try:
-    #             artwork_item.config()
-    #             config_artworks.append(artwork_item)
-    #         except ArtworkError as e:
-    #             failed_config_artworks[str(e)] = artwork_item
-    #
-    #     for index, _ in enumerate(pool.imap_unordered(config_artwork, artworks)):
-    #         util.print_progress(index + 1, total)
-    #
-    #     msg = f'expected: {total} | success: {len(config_artworks)} | failed: {len(failed_config_artworks)}'
-    #     util.print_done(msg)
-    #
-    #     if failed_config_artworks:
-    #         for index, item in enumerate(failed_config_artworks.items()):
-    #             util.log(f'Artwork with id: {item[1].id} failed config for download: {item[0]}', error=True)
-    #
-    #     return config_artworks
-
     def download(self, pikax_result: PikaxResult, folder: str = ''):
 
         if not folder:
@@ -371,39 +350,53 @@ class BaseDownloader:
         skips = []
         total_pages = sum(len(artwork) for artwork in artworks)
         total_artworks = len(artworks)
-        curr_page = 0
-        curr_artwork = 0
+        running_page_count = 0
+        running_artwork_count = 0
         pool = Pool()
-        util.log(f'Downloading Artworks | {total_pages} pages from {total_artworks} artworks', start=os.linesep,
-                 inform=True)
+        util.log(texts.ARTWORK_DOWNLOAD_INFO.format(total_artworks=total_artworks, total_pages=total_pages),
+                 start=os.linesep, inform=True)
 
         for download_details in pool.imap_unordered(download_function, artworks):
-            curr_artwork += 1
+            running_artwork_count += 1
             for download_detail in download_details:
-                curr_page += 1
-                if settings.MAX_PAGES_PER_ARTWORK and curr_page > settings.MAX_PAGES_PER_ARTWORK:
-                    break
+                running_page_count += 1
                 status, msg = download_detail
-                info = str(msg) + ' ' + str(status.value)
                 if status is Artwork.DownloadStatus.OK:
                     successes.append(msg)
                 elif status is Artwork.DownloadStatus.SKIPPED:
                     skips.append(msg)
                 else:
                     fails.append(msg)
-                info = f'{curr_artwork} / {total_artworks} ' \
-                       f'=> {math.ceil((curr_artwork / total_artworks) * 100)}% | ' + info
-                util.print_progress(curr_page, total_pages, msg=info)
+
+                msg = texts.GUI_ARTWORK_DOWNLOAD_HEADING + msg
+
+                artwork_progress_text = texts.DOWNLOAD_ARTWORK_PROGRESS_TEXT.format(
+                    curr=running_artwork_count, total=total_artworks,
+                    curr_percent=running_artwork_count / total_artworks * 100
+                )
+                pages_progress_text = texts.DOWNLOAD_PAGES_PROGRESS_TEXT.format(
+                    curr=running_page_count, total=total_pages,
+                    curr_percent=running_page_count / total_pages * 100
+                )
+                time_left_text = util.progress_printer.get_time_left_text(running_page_count, total_pages)
+                time_left_est = texts.TIME_LEFT_EST.format(time_left=time_left_text)
+                info = f'{msg} {status.value} | {pages_progress_text} | {artwork_progress_text} | {time_left_est}'
+                util.log(info, end='\r', inform=True)
         util.print_done()
 
-        util.log(f'There are {len(successes)} downloaded pages', inform=True)
+        # gather all end information before printing, mainly for gui,
+        # because every new output overwrites last printed text in the text component
+        end_info = texts.DOWNLOADED_PAGES_INFO.format(successes=len(successes))
 
-        util.log(f'There are {len(skips)} skipped pages', inform=True)
-        for index, skip_info in enumerate(skips):
-            util.log(skip_info, start=f' [{index + 1}] ', inform=True)
+        end_info += os.linesep + texts.SKIPPED_PAGES_INFO.format(skips=len(skips))
 
-        util.log(f'There are {len(fails)} failed pages', inform=True)
-        for index, skip_info in enumerate(fails):
-            util.log(skip_info, start=f' [{index + 1}] ', inform=True)
+        for index, skip_info in enumerate(skips, 1):
+            end_info += os.linesep + f' [{index}] ' + skip_info
 
-        util.print_done(str(folder))
+        end_info += os.linesep + texts.FAILED_PAGES_INFO.format(fails=len(fails))
+        for index, fail_info in enumerate(fails, 1):
+            end_info += os.linesep + f' [{index}] ' + fail_info
+
+        full_folder_path = os.path.join(Path(__file__).parent.absolute(), str(folder))
+        end_info += os.linesep + texts.DOWNLOAD_FINISHED_INFO_FOLDER.format(folder=str(full_folder_path))
+        util.log(end_info)
